@@ -10,7 +10,7 @@
 
 /**
  * @file
- * @brief System include files
+ * @brief System Include Files
  */
 
 #ifndef __DRIZZLE_COMMON_H
@@ -21,15 +21,24 @@
 #include "drizzle_client.h"
 #include "drizzle_server.h"
 
+#ifdef HAVE_ASSERT_H
 #include <assert.h>
+#endif
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
+#endif
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
 #ifdef HAVE_NETINET_TCP_H
 #include <netinet/tcp.h>
 #endif
+#ifdef HAVE_STDARG_H
+#include <stdarg.h>
+#endif
+#ifdef HAVE_STDIO_H
 #include <stdio.h>
+#endif
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -43,8 +52,8 @@
 #include <unistd.h>
 #endif
 
-#include "private.h"
-#include "conn_private.h"
+#include "drizzle_local.h"
+#include "conn_local.h"
 #include "pack.h"
 #include "state.h"
 #include "sha1.h"
