@@ -130,15 +130,16 @@ typedef enum
  */
 typedef enum
 {
-  DRIZZLE_CON_NONE=             0,
-  DRIZZLE_CON_ALLOCATED=        (1 << 0),
-  DRIZZLE_CON_MYSQL=            (1 << 1),
-  DRIZZLE_CON_RAW_PACKET=       (1 << 2),
-  DRIZZLE_CON_RAW_SCRAMBLE=     (1 << 3),
-  DRIZZLE_CON_READY=            (1 << 4),
-  DRIZZLE_CON_NO_RESULT_READ=   (1 << 5),
-  DRIZZLE_CON_IO_READY=         (1 << 6),
-  DRIZZLE_CON_LISTEN=           (1 << 7)
+  DRIZZLE_CON_NONE=           0,
+  DRIZZLE_CON_ALLOCATED=      (1 << 0),
+  DRIZZLE_CON_MYSQL=          (1 << 1),
+  DRIZZLE_CON_RAW_PACKET=     (1 << 2),
+  DRIZZLE_CON_RAW_SCRAMBLE=   (1 << 3),
+  DRIZZLE_CON_READY=          (1 << 4),
+  DRIZZLE_CON_NO_RESULT_READ= (1 << 5),
+  DRIZZLE_CON_IO_READY=       (1 << 6),
+  DRIZZLE_CON_LISTEN=         (1 << 7),
+  DRIZZLE_CON_EXPERIMENTAL=   (1 << 8)
 } drizzle_con_options_t;
 
 /**
