@@ -266,7 +266,7 @@ drizzle_con_st *drizzle_con_create(drizzle_st *drizzle, drizzle_con_st *con)
   con->capabilities= DRIZZLE_CAPABILITIES_NONE;
   con->charset= 0;
   con->command= 0;
-  /* con->options set above */
+  con->options|= DRIZZLE_CON_MYSQL;
   con->socket_type= DRIZZLE_CON_SOCKET_TCP;
   con->status= DRIZZLE_CON_STATUS_NONE;
   con->max_packet_size= DRIZZLE_MAX_PACKET_SIZE;
