@@ -10,7 +10,7 @@
 
 /**
  * @file
- * @brief Handshake declarations for clients
+ * @brief Handshake Declarations for Clients
  */
 
 #ifndef __DRIZZLE_HANDSHAKE_CLIENT_H
@@ -21,8 +21,9 @@ extern "C" {
 #endif
 
 /**
- * @addtogroup drizzle_handshake_client Handshake Functions for Clients
- * @ingroup drizzle_client
+ * @addtogroup drizzle_handshake_client Handshake Declarations for Clients
+ * @ingroup drizzle_client_interface
+ *
  * These functions are used to send and receive handshake packets for a client.
  * These are only used by low-level clients when the DRIZZLE_CON_RAW_PACKET
  * option is set, so most applications will never need to use these.
@@ -30,16 +31,24 @@ extern "C" {
  */
 
 /**
- * Read server handshake packet.
+ * Read handshake packet from the server in a client.
+ *
+ * @param[in] con Connection structure previously initialized with
+ *  drizzle_con_create(), drizzle_con_clone(), or related functions.
+ * @return Standard drizzle return value.
  */
 DRIZZLE_API
-drizzle_return_t drizzle_server_handshake_read(drizzle_con_st *con);
+drizzle_return_t drizzle_handshake_server_read(drizzle_con_st *con);
 
 /**
- * Write client handshake packet.
+ * Write client handshake packet to a server.
+ *
+ * @param[in] con Connection structure previously initialized with
+ *  drizzle_con_create(), drizzle_con_clone(), or related functions.
+ * @return Standard drizzle return value.
  */
 DRIZZLE_API
-drizzle_return_t drizzle_client_handshake_write(drizzle_con_st *con);
+drizzle_return_t drizzle_handshake_client_write(drizzle_con_st *con);
 
 /** @} */
 
