@@ -192,6 +192,44 @@ void drizzle_query_set_context_free_fn(drizzle_query_st *query,
   query->context_free_fn= function;
 }
 
+static void drizzle_query_run_state(drizzle_query_st* query,
+                                    drizzle_return_t* ret_ptr)
+{
+  switch (query->state)
+  {
+  case DRIZZLE_QUERY_STATE_INIT:
+    query->state= DRIZZLE_QUERY_STATE_QUERY;
+  case DRIZZLE_QUERY_STATE_QUERY:
+    query->result= drizzle_query(query->con, query->result, query->string,
+                                 query->size, ret_ptr);
+    if (*ret_ptr == DRIZZLE_RETURN_IO_WAIT)
+    {
+      return;
+    }
+    else if (*ret_ptr != DRIZZLE_RETURN_OK)
+    {
+      query->state= DRIZZLE_QUERY_STATE_DONE;
+      return;
+    }
+
+    query->state= DRIZZLE_QUERY_STATE_RESULT;
+
+  case DRIZZLE_QUERY_STATE_RESULT:
+    *ret_ptr= drizzle_result_buffer(query->result);
+    if (*ret_ptr == DRIZZLE_RETURN_IO_WAIT)
+    {
+      return;
+    }
+
+    query->state= DRIZZLE_QUERY_STATE_DONE;
+    return;
+
+  default:
+  case DRIZZLE_QUERY_STATE_DONE:
+    return;
+  }
+}
+
 drizzle_query_st *drizzle_query_run(drizzle_st *drizzle,
                                     drizzle_return_t *ret_ptr)
 {
@@ -216,27 +254,26 @@ drizzle_query_st *drizzle_query_run(drizzle_st *drizzle,
       if (query->state != DRIZZLE_QUERY_STATE_INIT)
         continue;
 
-      query->result= drizzle_query(query->con, query->result, query->string,
-                                   query->size, ret_ptr);
-      if (*ret_ptr != DRIZZLE_RETURN_IO_WAIT && *ret_ptr != DRIZZLE_RETURN_OK)
-      {
-        drizzle->options= options;
+      drizzle->query_new--;
+      drizzle->query_running++;
+      assert(query->con->query == NULL);
+      query->con->query= query;
 
-        if (*ret_ptr == DRIZZLE_RETURN_ERROR_CODE)
+      drizzle_query_run_state(query, ret_ptr);
+      if (*ret_ptr != DRIZZLE_RETURN_IO_WAIT)
+      {
+        assert(query->state == DRIZZLE_QUERY_STATE_DONE);
+        drizzle->query_running--;
+        drizzle->options= options;
+        query->con->query= NULL;
+        if (*ret_ptr == DRIZZLE_RETURN_ERROR_CODE || *ret_ptr == DRIZZLE_RETURN_OK)
         {
-          query->state= DRIZZLE_QUERY_STATE_DONE;
-          drizzle->query_new--;
           return query;
         }
-
         return NULL;
       }
-
-      query->state= DRIZZLE_QUERY_STATE_QUERY;
-      drizzle->query_running++;
-      query->con->query= query;
-      drizzle->query_new--;
     }
+    assert(drizzle->query_new == 0);
   }
 
   while (1)
@@ -245,49 +282,15 @@ drizzle_query_st *drizzle_query_run(drizzle_st *drizzle,
     while ((con= drizzle_con_ready(drizzle)) != NULL)
     {
       query= con->query;
-
-      switch (query->state)
+      drizzle_query_run_state(query, ret_ptr);
+      if (query->state == DRIZZLE_QUERY_STATE_DONE)
       {
-      case DRIZZLE_QUERY_STATE_INIT:
-      case DRIZZLE_QUERY_STATE_QUERY:
-        query->result= drizzle_query(query->con, query->result, query->string,
-                                     query->size, ret_ptr);
-        if (*ret_ptr == DRIZZLE_RETURN_IO_WAIT)
-          break;
-        else if (*ret_ptr == DRIZZLE_RETURN_ERROR_CODE)
-        {
-          query->state= DRIZZLE_QUERY_STATE_DONE;
-          drizzle->query_running--;
-          drizzle->options= options;
-          return query;
-        }
-        else if (*ret_ptr != DRIZZLE_RETURN_OK)
-        {
-          drizzle->options= options;
-          return NULL;
-        }
-
-        query->state= DRIZZLE_QUERY_STATE_RESULT;
-
-      case DRIZZLE_QUERY_STATE_RESULT:
-        *ret_ptr= drizzle_result_buffer(query->result);
-        if (*ret_ptr == DRIZZLE_RETURN_IO_WAIT)
-          break;
-        if (*ret_ptr != DRIZZLE_RETURN_OK)
-        {
-          drizzle->options= options;
-          return NULL;
-        }
-
-        query->state= DRIZZLE_QUERY_STATE_DONE;
         drizzle->query_running--;
         drizzle->options= options;
+        con->query= NULL;
         return query;
-
-      default:
-      case DRIZZLE_QUERY_STATE_DONE:
-        break;
       }
+      assert(*ret_ptr == DRIZZLE_RETURN_IO_WAIT);
     }
 
     if (options & DRIZZLE_NON_BLOCKING)
