@@ -20,10 +20,16 @@
 #include <libdrizzle/drizzle_client.h>
 #include <libdrizzle/drizzle_server.h>
 
-#define DRIZZLE_TEST_ERROR(...) \
+#define drizzle_test(...) do \
 { \
-  printf("*** %s:%d:", __FILE__, __LINE__); \
+  printf(__VA_ARGS__); \
+  printf("\n"); \
+} while (0);
+
+#define drizzle_test_error(...) do \
+{ \
+  printf("*** %s:%d *** ", __FILE__, __LINE__); \
   printf(__VA_ARGS__); \
   printf("\n"); \
   exit(1); \
-}
+} while (0);
