@@ -23,29 +23,29 @@ int main(void)
   drizzle_result_st result_buffer;
   drizzle_result_st *clone;
 
-  printf("# sizeof(drizzle_result_st) = %zu\n", sizeof(drizzle_result_st));
+  printf("sizeof(drizzle_result_st) = %zu\n", sizeof(drizzle_result_st));
 
   if ((drizzle= drizzle_create(NULL)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_create");
+    drizzle_test_error("drizzle_create");
 
   if ((con= drizzle_con_create(drizzle, NULL)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_con_create");
+    drizzle_test_error("drizzle_con_create");
 
   if ((result= drizzle_result_create(con, &result_buffer)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_result_create");
+    drizzle_test_error("drizzle_result_create");
   drizzle_result_free(result);
 
   if ((result= drizzle_result_create(con, NULL)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_result_create");
+    drizzle_test_error("drizzle_result_create");
 
   if ((clone= drizzle_result_clone(con, NULL, result)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_result_clone");
+    drizzle_test_error("drizzle_result_clone");
   drizzle_result_free(clone);
 
   drizzle_result_set_info(result, "simple test");
 
   if (strcmp(drizzle_result_info(result), "simple test"))
-    DRIZZLE_TEST_ERROR("drizzle_result_info");
+    drizzle_test_error("drizzle_result_info");
 
   drizzle_result_free(result);
   drizzle_con_free(con);
