@@ -9,11 +9,20 @@
 # the COPYING file in this directory for full text.
 #
 
-libtool_prefix="libtool --mode=execute"
-
 # Get filename we want to run without path
 name=`echo $1 | sed 's/.*\/\([^\/]*\)$/\1/'`
 
+ext=`echo $name | sed 's/.*\.\([^.]*$\)/\1/'`
+if [ "x$ext" = "x$name" ]
+then
+  ext=""
+fi
+
+if [ ! "x$ext" = "xsh" ]
+then
+  libtool_prefix="libtool --mode=execute"
+fi
+
 # Set prefix if it was given through environment
 if [ -n "$LIBDRIZZLE_TEST_PREFIX" ]
 then
